{% load i18n %}
{% load url from future %}
<!doctype html>
<html lang="{{ LANGUAGE_CODE }}">
  <head>
    <meta charset="utf-8">
    <title>Zinnia's Blog - {% block title %}{% endblock %}</title>
    <meta name="robots" content="follow, all" />
    <meta name="viewport" content="width=device-width, initial-scale=1.0" />
    <meta name="description" content="{% block meta-description %}Demonstration of the Zinnia Blog application.{% endblock %}" />
    <meta name="keywords" content="{% block meta-keywords %}django, blog, zinnia{% endblock %}" />
    <meta name="author" content="Fantomas42" />
    {% block meta %}{% endblock %}
    <link rel="pingback" href="/xmlrpc/" />
    <link rel="home" href="{% url 'zinnia_entry_archive_index' %}" />
    <link href="{{ STATIC_URL }}zinnia_bootstrap/bootstrap/css/bootstrap.css" rel="stylesheet">
    <style type="text/css">
      body {
        padding-top: 40px;
      }
    </style>
    <link href="{{ STATIC_URL }}zinnia_bootstrap/bootstrap/css/bootstrap-responsive.css" rel="stylesheet">
    <!--[if lt IE 9]>
      <script src="http://html5shim.googlecode.com/svn/trunk/html5.js"></script>
    <![endif]-->
    <link rel="shortcut icon" href="{{ STATIC_URL }}zinnia/img/favicon.ico" />
    <link rel="apple-touch-icon-precomposed" sizes="144x144" href="{{ STATIC_URL }}zinnia_bootstrap/bootstrap/ico/apple-touch-icon-144-precomposed.png">
    <link rel="apple-touch-icon-precomposed" sizes="114x114" href="{{ STATIC_URL }}zinnia_bootstrap/bootstrap/ico/apple-touch-icon-114-precomposed.png">
    <link rel="apple-touch-icon-precomposed" sizes="72x72" href="{{ STATIC_URL }}zinnia_bootstrap/bootstrap/ico/apple-touch-icon-72-precomposed.png">
    <link rel="apple-touch-icon-precomposed" href="{{ STATIC_URL }}zinnia_bootstrap/bootstrap/ico/apple-touch-icon-57-precomposed.png">
    {% block link %}{% endblock %}
    {% block script %}{% endblock %}
  </head>
  <body class="zinnia {% block body-class %}{% endblock %}">
    <header class="navbar navbar-fixed-top">
      <div class="navbar-inner">
        <div class="container">
          <img src="{{ STATIC_URL }}zinnia_bootstrap/img/zinnia.png" class="pull-left" />
          <a href="{% url 'zinnia_entry_archive_index' %}" title="Zinnia's Blog" class="brand" rel="home">
            Zinnia's Blog
          </a>
          <ul class="nav pull-left">
            {% url 'zinnia_category_list' as category_list_url %}
            <li {% if category_list_url in request.path %}class="active"{% endif %}>
              <a href="{{ category_list_url }}" title="{% trans "Category list" %}">
                {% trans "Categories" %}
              </a>
            </li>
            {% url 'zinnia_author_list' as author_list_url %}
            <li {% if author_list_url in request.path %}class="active"{% endif %}>
              <a href="{{ author_list_url }}" title="{% trans "Author list" %}">
                {% trans "Authors" %}
              </a>
            </li>
            {% url 'zinnia_tag_list' as tag_list_url %}
            <li {% if tag_list_url in request.path %}class="active"{% endif %}>
              <a href="{{ tag_list_url }}" title="{% trans "Tag list" %}">
                {% trans "Tags" %}
              </a>
            </li>
            <li class="divider-vertical"></li>
          </ul>
          <form method="get" action="{% url 'zinnia_entry_search' %}" class="navbar-search pull-left">
            <input type="text" class="search-query" placeholder="{% trans 'Search' %}" name="pattern" value="{{ pattern }}" />
          </form>
          <ul class="nav pull-right">
            {% url 'zinnia_sitemap' as sitemap_url %}
            <li {% if sitemap in request.path %}class="active"{% endif %}>
            <li>
              <a href="{{ sitemap_url }}" title="{% trans "Sitemap" %}" class="sitemap">
                {% trans "Sitemap" %}
              </a>
            </li>
            <li class="divider-vertical"></li>
            <li>
              <a href="{% url 'zinnia_entry_latest_feed' %}" title="{% trans "RSS Feed of latest entries" %}" class="feeds">
                {% trans "RSS Feed" %}
              </a>
            </li>
          </ul>
        </div>
      </div>
    </header>
    <div class="container">
      {% block breadcrumbs %}{% endblock %}
    </div>
    {% block slider %}{% endblock %}
    <div class="container">
      <div class="row">
        <div id="content" class="hfeed span8">
          {% block content %}
          <div class="links">
            <h3>{% trans "Useful links" %}</h3>
            <ul>
              <li>
                <a href="{% url 'zinnia_entry_archive_index' %}" title="{% trans "Blog index" %}">
                  {% trans "Blog index" %}
                </a>
              </li>
              <li>
                <a href="{% url 'zinnia_sitemap' %}" title="{% trans "Sitemap" %}">
                  {% trans "Sitemap" %}
                </a>
              </li>
            </ul>
          </div>
          <div class="search">
            <h3>{% trans "Search" %}</h3>
            {% include "zinnia/tags/search_form.html" %}
          </div>
          {% endblock %}
        </div>
        <div id="sidebar" class="span4">
          <div id="widget-welcome" class="widget well">
            <h3>Welcome!</h3>
            <p>
              This simple skin is a base theme implementing Twitter's Bootstrap CSS toolkit.
            </p>
          </div>
          {% block sidebar %}
          {% endblock %}
        </div>
      </div>
    </div>
    <footer class="container">
      <p>Powered by <a href="http://www.djangoproject.com">Django</a> and <a href="https://github.com/Fantomas42/django-blog-zinnia">Zinnia {{ ZINNIA_VERSION }}</a>.</p>
    </footer>
  </body>
</html>
