{% load i18n %}
<ul class="nav nav-tabs nav-stacked">
  {% for author in authors %}
  <li class="vcard{% if author.username == context_author.username %} current{% endif %}>">
    <a href="{{ author.get_absolute_url }}"
       title="{% blocktrans %}Show all {{ author }}'s entries{% endblocktrans %}"
       class="fn nickname url">{{ author }}
      <span class="label label-info">
        {% blocktrans count entry_count=author.count_entries_published %}{{ entry_count }} entry{% plural %}{{ entry_count }} entries{% endblocktrans %}
      </span>
    </a>
  </li>
  {% empty %}
  <li>
    {% trans "No authors yet." %}
  </li>
  {% endfor %}
</ul>
