{% load i18n %}
<ul class="nav nav-tabs nav-stacked">
  {% for entry in entries %}
  <li>
    <a href="{{ entry.get_absolute_url }}" title="{{ entry.title }}" rel="bookmark">{{ entry.title }}</a>
  </li>
  {% empty %}
  <li>
    <a href="#">{% trans "No entries yet." %}</a>
  </li>
  {% endfor %}
</ul>
